Crate titan_api_codec

Crate titan_api_codec 

Utilities for encoding and decoding Titan API messages to and from their binary representations.

The current v1 API encodes messages using MessagePack, with optional compression on the binary encoding.

Features

The following features control various compression methods:

  • brotli - (default) Enables brotli transforms for encoding and decoding.
  • gzip - (default) Enables gzip transforms for encoding and decoding.
  • zstd - (default) Enables zstd transforms for encoding and decoding.

The following features control various encoding methods:

  • messagepack - (default) Enables MessagePack encoding and decoding.

Additional features:

  • enum-other - (default) Enables enum-other feature on titan-api-types crate, allowing for handling of message types not defined in this version of the codec, e.g. for error handling.

Modules

codec
Defines codecs for encoding and decoding messages for versions of the Titan API with optional compression and possibly other options.
dec
Utilities for decoding messages from binary representations.
enc
Utilities for encoding messages to binary representation.
transform
Defines transforms that are performs post-serialization or pre-deserialization.