Module codec

Module codec 

Defines codecs for encoding and decoding messages for versions of the Titan API with optional compression and possibly other options.

Modules

ws
Versioned Codecs for the Titan WebSocket API.

Structs

WrappedDecoder
Wraps a Decoder, attempting to decode a specific message type from provided data.
WrappedEncoder
Wraps an Encoder, restricting thet type of message that can be encoded.

Enums

CodecLoadError
Errors that can occur while attempting to load a codec.

Traits

Codec
Represents a specific encoding and decoding scheme for one side of a connection.
TypedDecoder
A decoder that decodes a specific type of message.
TypedEncoder
An encoder that encodes a specific type of message.