CodecLoadError

Enum CodecLoadError 

pub enum CodecLoadError {
    UnsupportedProtocol(String),
    DisabledEncoding(&'static str),
}
Errors that can occur while attempting to load a codec.

Variants



UnsupportedProtocol(String)

Protocol is unsupported.

Normally wil be caused by the client requesting a different version than the server supports.



DisabledEncoding(&'static str)

Requested protocol and encoding is valid, but the encoding method is disabled.