pub struct WrappedDecoder<T, D> { /* private fields */ }Expand description
Wraps a Decoder, attempting to decode a specific message type from provided data.
Implementations
Sourceimpl<T, E> WrappedDecoder<T, E>
impl<T, E> WrappedDecoder<T, E>
Sourcepub fn new(decoder: E) -> Self
pub fn new(decoder: E) -> Self
Creates a new WrappedDecoder using the given Decoder.
The new decoder is a TypedDecoder that attempts to decode values of type T from
provided data.