TypedDecoder

Trait TypedDecoder 

pub trait TypedDecoder {
    type Item;
    type Error;

    // Required methods
    fn decode(&self, data: Bytes) -> Result<Self::Item, Self::Error>;
    fn decode_mut(&mut self, data: Bytes) -> Result<Self::Item, Self::Error>;
}
A decoder that decodes a specific type of message.

Required Associated Types

type Item

The type of messages this Decoder decodes.

type Error

Type of error returned by this decoder if decoding fails.

Required Methods

fn decode(&self, data: Bytes) -> Result<Self::Item, Self::Error>

Attempt to decode the given data into a value.

fn decode_mut(&mut self, data: Bytes) -> Result<Self::Item, Self::Error>

Attempt to decode the given data into a value, mutating the decoder’s state if doing so provides a benefit.

Implementors