Module common

Module common 

Common traits and implementations for decoding of messages from binary representations.

Structs

TransformedDecoder
A decoder that wraps another Decoder, first applying a BinaryTransform to the data.

Enums

DecodeError
Possible errors that can occur while decoding messages.

Traits

Decoder
A decoder that can transform binary data into a serde-deserializable object.