Module common

Module common 

Common traits and implementations for binary encoding of messages.

Structs

TransformedEncoder
An encoder that applies a transform to data encoded by another encoder.

Enums

EncodeError
Possible errors that can occur while encoding messages.

Traits

Encoder
An encoder that can transform a serde-serializable object into binary data.