Module gzip

Module gzip 

Defines transforms that utilize gzip to compress and decompress data.

Structs

GzipCompressor
Transform that applies gzip compression to the input.
GzipDecompressor
Transform that takes gzip-compressed data and inflates it back to its original content.