Common traits and implementations for decoding of messages from binary representations.
Structs
- Transformed
Decoder - A decoder that wraps another
Decoder, first applying aBinaryTransformto the data.
Enums
- Decode
Error - Possible errors that can occur while decoding messages.
Traits
- Decoder
- A decoder that can transform binary data into a serde-deserializable object.